Package: pbdZMQ
Version: 0.3-13
Date: 2024-09-15
Title: Programming with Big Data -- Interface to 'ZeroMQ'
Authors@R: c(person("Wei-Chen", "Chen", role = c("aut", "cre"), email =
        "wccsnow@gmail.com"),
        person("Drew", "Schmidt", role = "aut"),
        person("Christian", "Heckendorf", role = "aut", comment = "file transfer"),
        person("George", "Ostrouchov", role = "aut", comment = "Mac OSX"),
        person("Whit", "Armstrong", role = "ctb", comment = "some functions
                are modified from the rzmq package for backwards compatibility"),
        person("Brian", "Ripley", role = "ctb",
               comment = "C code of shellexec, and Solaris"),
        person("R Core team", role = "ctb", comment = "some functions and
                headers are copied or modified from the R source code"),
        person("Philipp", "A.", role = "ctb", comment = "Fedora"),
        person("Elliott Sales", "de Andrade", role = "ctb", comment = "sprintf"),
        person("Spencer", "Aiello", role = "ctb", comment = "windows conf"),
        person("Paul", "Andrey", role = "ctb", comment = "Mac OSX conf"),
        person("Panagiotis", "Cheilaris", role = "ctb", comment = "add serialize version"),
        person("Jeroen", "Ooms", role = "ctb", comment = "clang++ on MacOS ARM64"),
        person("ZeroMQ authors", role = c("aut", "cph"), comment = "source files in 'src/zmq_src/'")
	)
Depends: R (>= 3.5.0)
LazyLoad: yes
Copyright: See files AUTHORS, COPYING, and COPYING.LESSER in
        'inst/zmq_copyright/' for the 'ZeroMQ' source files in
        'src/zmq_src/' which are under GPL-3.
Description: 'ZeroMQ' is a well-known library for high-performance
    asynchronous messaging in scalable, distributed applications.  This
    package provides high level R wrapper functions to easily utilize
    'ZeroMQ'. We mainly focus on interactive client/server programming
    frameworks. For convenience, a minimal 'ZeroMQ' library (4.2.2)
    is shipped with 'pbdZMQ', which can be used if no system installation
    of 'ZeroMQ' is available.  A few wrapper functions compatible with
    'rzmq' are also provided.
SystemRequirements: Linux, Mac OSX, and Windows, or 'ZeroMQ' library >=
        4.0.4. Solaris 10 needs 'ZeroMQ' library 4.0.7 and 'OpenCSW'.
StagedInstall: TRUE
License: GPL-3
URL: https://pbdr.org/
BugReports: https://github.com/snoweye/pbdZMQ/issues
NeedsCompilation: yes
Maintainer: Wei-Chen Chen <wccsnow@gmail.com>
RoxygenNote: 7.2.3
Packaged: 2024-09-15 19:14:05 UTC; snoweye
Author: Wei-Chen Chen [aut, cre],
  Drew Schmidt [aut],
  Christian Heckendorf [aut] (file transfer),
  George Ostrouchov [aut] (Mac OSX),
  Whit Armstrong [ctb] (some functions are modified from the rzmq package
    for backwards compatibility),
  Brian Ripley [ctb] (C code of shellexec, and Solaris),
  R Core team [ctb] (some functions and headers are copied or modified
    from the R source code),
  Philipp A. [ctb] (Fedora),
  Elliott Sales de Andrade [ctb] (sprintf),
  Spencer Aiello [ctb] (windows conf),
  Paul Andrey [ctb] (Mac OSX conf),
  Panagiotis Cheilaris [ctb] (add serialize version),
  Jeroen Ooms [ctb] (clang++ on MacOS ARM64),
  ZeroMQ authors [aut, cph] (source files in 'src/zmq_src/')
Repository: CRAN
Date/Publication: 2024-09-17 08:40:02 UTC
Built: R 4.4.2; aarch64--netbsd; 2025-12-29 13:51:07 UTC; unix
