Package: pbdZMQ
Version: 0.2-4
Date: 2016-09-21
Title: Programming with Big Data -- Interface to ZeroMQ
Authors@R: c(person("Wei-Chen", "Chen", role = c("aut", "cre"), email =
        "wccsnow@gmail.com"),
        person("Drew", "Schmidt", role = "aut"),
        person("Christian", "Heckendorf", role = "aut", comment = "file transfer"),
        person("George", "Ostrouchov", role = "aut", comment = "Mac OSX"),
        person("Whit", "Armstrong", role = "ctb", comment = "some functions
                are modified from the rzmq package for backwards compatibility"),
        person("Brian", "Ripley", role = "ctb",
               comment = "C code of shellexec, and Solaris"),
        person("R Core team", role = "ctb", comment = "some functions are
                modified from the R source code"),
        person("Philipp", "A.", role = "ctb", comment = "Fedora"))
Depends: R (>= 3.0.0)
Imports: R6
LazyLoad: yes
LazyData: yes
Copyright: See files AUTHORS, COPYING, COPYING.LESSER, and MAINTAINERS
        in pbdZMQ/inst/zmq_copyright/ for the ZeroMQ source files in
        src/zmq_src/ which are under GPL-3.
Description: 'ZeroMQ' is a well-known library for high-performance
    asynchronous messaging in scalable, distributed applications.  This
    package provides high level R wrapper functions to easily utilize
    'ZeroMQ'. We mainly focus on interactive client/server programming
    frameworks. For convenience, a minimal 'ZeroMQ' library (4.1.0 rc1)
    is shipped with 'pbdZMQ', which can be used if no system installation
    of 'ZeroMQ' is available.  A few wrapper functions compatible with
    'rzmq' are also provided.
SystemRequirements: Linux, Mac OSX, and Windows, or ZeroMQ library >=
        4.0.4. Solaris 10 needs ZeroMQ library 4.0.7 and OpenCSW.
License: GPL-3
URL: http://r-pbd.org/
BugReports: http://group.r-pbd.org/
MailingList: Please send questions and comments regarding pbdR to
        RBigData@gmail.com
NeedsCompilation: yes
Packaged: 2016-09-22 00:19:47 UTC; snoweye
Author: Wei-Chen Chen [aut, cre],
  Drew Schmidt [aut],
  Christian Heckendorf [aut] (file transfer),
  George Ostrouchov [aut] (Mac OSX),
  Whit Armstrong [ctb] (some functions are modified from the rzmq package
    for backwards compatibility),
  Brian Ripley [ctb] (C code of shellexec, and Solaris),
  R Core team [ctb] (some functions are modified from the R source code),
  Philipp A. [ctb] (Fedora)
Maintainer: Wei-Chen Chen <wccsnow@gmail.com>
Repository: CRAN
Date/Publication: 2016-09-22 09:22:53
Built: R 3.3.2; x86_64-w64-mingw32; 2017-02-18 16:27:58 UTC; windows
Archs: x64
